@@ -158,6 +158,12 @@ class SqlServer:
             "com.microsoft.sqlserver.jdbc.spark" if big_data_set else "jdbc"
         ).mode("append" if append else "overwrite").option(
             "schemaCheckEnabled", False
+        ).option(
+            # https://learn.microsoft.com/en-us/sql/connect/spark/connector?view=sql-server-ver16#supported-options
+            # https://github.com/microsoft/sql-spark-connector/blob/master/README.md
+            # Implements an insert with TABLOCK option to improve write performance
+            "tableLock",
+            True,
         ).option(
             "batchSize", batch_size
         ).option(
